#
# spec file for package glab
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021-2022 Orville Q. Song <orville@anislet.dev>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           glab
Version:        1.49.0
Release:        1.1
Summary:        A GitLab command line tool
License:        MIT
Group:          Development/Tools/Other
URL:            https://gitlab.com/gitlab-org/cli
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?almalinux_version} || 0%{?rocky_version}
BuildRequires:  golang >= 1.23.0
%else
BuildRequires:  go1.23 >= 1.23.0
BuildRequires:  golang-packaging
%endif
Suggests:       glab-doc

%description
glab is a command line tool bringing GitLab's features to the command line.

%package doc
Summary:        Documentation for GLab
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
glab is a command line tool bringing GitLab's features to the command line.

%package bash-completion
Summary:        Bash completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n %{name}-%{version}

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
        -mod=vendor \
        -buildmode=pie \
        -ldflags "-s -w -X main.version=%{version} -X main.build=$BUILD_DATE -X main.debugMode=false" \
        ./cmd/glab

# Build HTML docs
go run ./cmd/gen-docs/docs.go

# Build manpages
go run -v -p 4 -x -mod=vendor ./cmd/gen-docs/docs.go --manpage --path ./share/man/man1
gzip -r ./share/man/man1

# Generate completion files
go run -v -p 4 -x -mod=vendor ./cmd/glab/ completion -s bash > %{name}.bash
go run -v -p 4 -x -mod=vendor ./cmd/glab/ completion -s zsh > %{name}.zsh
go run -v -p 4 -x -mod=vendor ./cmd/glab/ completion -s fish > %{name}.fish

%install
mkdir -p "%{buildroot}/%{_bindir}/"
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

# Install HTML docs
mkdir -p "%{buildroot}/%{_docdir}/%{name}/"
cp -vr ./docs/source/* %{buildroot}%{_docdir}/%{name}/
find %{buildroot}%{_docdir}/%{name}/ -type f -exec chmod 644 {} "+"
find %{buildroot}%{_docdir}/%{name}/ -type d -exec chmod 755 {} "+"

# Install manpages
mkdir -p "%{buildroot}/%{_mandir}/man1/"
cp ./share/man/man1/* %{buildroot}%{_mandir}/man1/
find %{buildroot}%{_mandir}/man1/ -type f -exec chmod 644 {} "+"

# Install completion files
install -D -m0644 %{name}.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -D -m0644 %{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -D -m0644 %{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}

%files
%license LICENSE
%doc README.md
%{_mandir}/*/*
%{_bindir}/%{name}

%files doc
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/README.md

%files bash-completion
%dir %{_datadir}/bash-completion/
%{_datadir}/bash-completion/completions/

%files fish-completion
%dir %{_datadir}/fish/
%{_datadir}/fish/vendor_completions.d/

%files zsh-completion
%dir %{_datadir}/zsh/
%{_datadir}/zsh/site-functions/

%changelog
* Fri Nov 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.49.0:
  * chore: Restore markdownlint testing, disable rule MD029 for
    ol-prefix
  * fix(stacked-diffs): remove merged or closed MRs in sync
  * feat(test): Integration test for create issue with recover
    option
  * docs: Spacing, capitalization, and punctuation
  * fix(commands/cluster/agent/get_token): agentID is always 64 bit
  * feat(release): "release create --tag-message" flag
  * refactor: Remove package-level vars
  * fix(diff): return most recent diff version only
  * chore(deps): update module golang.org/x/oauth2 to v0.24.0
  * chore(deps): update module golang.org/x/crypto to v0.29.0
  * feat: list personal, project or group access tokens
  * chore(deps): update module github.com/xanzy/go-gitlab to
    v0.113.0
  * test: Adding checking of post body to http mocks
  * chore(license): Update LICENSE
  * docs: add flux bootstrap path note to agent bootstrap cmd
  * docs: ignore generated documentation when running
    markdownlint-cli2
  * fix: add more info to gitlab agent reconcile error
  * chore(deps): update module github.com/zalando/go-keyring to
    v0.2.6
  * chore(deps): update module k8s.io/client-go to v0.31.2
  * chore(deps): update module k8s.io/apimachinery to v0.31.2
  * feat: add environment format for variable export
  * feat(auth login): allow more non-interactive login options
  * feat(issues): add filter by iteration option to issue list
  * feat: rotate personal, project or group access tokens
  * fix: utilize api_host in config to avoid git subdomain issues
  * chore(deps): update module go.uber.org/mock to v0.5.0
  * feat(agent bootstrap): support specifying Agent Helm Chart
    values
* Thu Oct 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.48.0:
  * docs: Explain set-upstream for stacks in forks
  * chore(release): release for freebsd and ppc64le
  * feat: configure KAS address explicitly in agent bootstrapping
  * feat: add token id reference to agent secret
  * feat: implement environment and dashboard support
  * chore(deps): update module github.com/xanzy/go-gitlab to
    v0.112.0
  * refactor(pkg/utils): Add require.Equals in pkg/utils_test.go
  * chore: use goreleaser nightly
  * chore(deps): update golang to v1.23.2
  * fix(staging): consider foo.gitlab.com self managed
  * chore(deps): update module github.com/xanzy/go-gitlab to
    v0.111.0
  * chore(go-gitlab): bump to 0.110.0
  * chore: make goreleaser use the go version in GitLab CI
  * docs: Add notes on discussing large contributions
  * chore(deps): update module golang.org/x/crypto to v0.28.0
  * chore(deps): update module golang.org/x/text to v0.19.0
  * feat:  revoke personal, project and group access tokens
  * docs: make documentation conform to linting rules
  * chore: update linting tools and configuration
  * feat: add `stack switch` command
  * chore: don't run 'release-test' for actual releases
* Thu Oct  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.47.0:
  * feat(stacked-diffs): Add origin fetch so sync will fully
    pull+push
  * docs: revise token-create page lightly
  * feat(stack): introduce stack list command
  * fix: use conventional linux package and archive file names
  * chore(ci): run build_windows asap
  * fix(stacked-diffs): fix MR creation for forks
  * feat: cluster agent bootstrap command
  * fix: glab mr view prompt disabled if NO_PROMPT is set with
    multiple mr
  * chore: insert commit subject + body to MR template descriptions
  * chore: increase size of CI runners
  * chore: optimize pipeline runtime
  * feat: create personal, project or group tokens
  * chore(deps): update @commitlint/config-conventional to ^19.5.0
  * fix(repo clone): fix --with-shared behaviour
  * chore: bump code intel component to v0.0.3
  * chore(deps): update module k8s.io/client-go to v0.31.1
  * chore(deps): update dependency @commitlint/lint to ^19.5.0
  * fix: revise docker image dependencies
  * chore(deps): update dependency @commitlint/format to ^19.5.0
  * chore(deps): update golang to v1.23.1
  * chore(deps): update module golang.org/x/oauth2 to v0.23.0
* Wed Sep 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.46.1:
  * fix(login): use verifier to create oauth challenge
  * docs: fix violation of updated linting rules
  * chore(deps): use latest docs Docker image and linting
    configuration
  * chore(deps): update module golang.org/x/crypto to v0.27.0
  * chore(deps): update module golang.org/x/text to v0.18.0
  * fix(typo): update token generation URL
  * chore(deps): update module golang.org/x/term to v0.24.0
* Mon Sep  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.46.0:
  * fix: fix example command for stack sync
  * refactor: Add a more secure way to generate a random string
  * chore(deps): update dependency axios to ^1.7.7
  * fix(api): ensure stable sorting of MRs by descending CreatedAt
  * feat(variable get): allow scope for group vars
  * chore(deps): update dependency @commitlint/lint to ^19.4.1
  * chore: add GitLab Advanced SAST to CI/CD config
  * style: Removing `exportloopref` since we're using go 1.22
  * fix(api): enable group MR listing with reviewer and assignee
    filters
  * chore(deps): update dependency axios to ^1.7.5
  * chore: remove space before colons
  * chore: update code intelligence component to v0.0.2
  * feat(stack): stack save/amend use $EDITOR
  * chore(deps): upgrade to go 1.23
  * feat: repo list include/exclude subgroups and archived support
  * fix(snippet create): allow for stdin
  * chore: switch to code intel CI/CD Component
  * chore(deps): update module golang.org/x/text to v0.17.0
  * chore(deps): update module golang.org/x/crypto to v0.26.0
  * chore(deps): update dependency axios to ^1.7.4
  * fix: restrict zip decompression
  * chore(deps): update module k8s.io/client-go to v0.31.0
  * chore: update axios for commit lint
  * chore(deps): update module golang.org/x/sync to v0.8.0
  * chore(deps): update module github.com/spf13/cast to v1.7.0
  * Gitignore gitlab reports
  * chore(deps): update module golang.org/x/term to v0.23.0
  * chore(deps): update module github.com/charmbracelet/glamour to
    v0.8.0
  * docs(installation): Add ASDF section in the
    installation_options TOC
  * fix(release upload): fix asset URL format for uploads in GitLab
    17.2
  * chore(deps): update dependency axios to ^1.7.3
  * chore(deps): update module github.com/xanzy/go-gitlab to
    v0.107.0
  * chore: Merge security fixes
  * docs: Adding snapcraft info
  * chore: Downcase 'personal access token' (CLI)
  * chore: catch up security fork
  * chore: merge security branch
  * test(duo ask): integration test for duo ask
* Thu Aug  1 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.45.0:
  * Go mod tidy
  * fix: validate state parameter passed in OAuth2 login
  * Address linter findings for stack save
  * Add current timestamp to hashed data in stack save
  * Rework stack save to make hashes without exec
  * Fix command injection stack save, remove newline from hash gen
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.44.1 (1.44.0 was not released):
  * chore: CI/CD changes to fix release bug
  * chore(deps): update module github.com/mattn/go-runewidth to
    v0.0.16
  * fix(ci view): pipeline creator is shown incorrectly
  * chore(deps): update module k8s.io/client-go to v0.30.3
  * chore(deps): update module k8s.io/apimachinery to v0.30.3
  * fix(config): negate `HasSecurePerms` and fix workaround on
    windows
  * chore(deps): update golang to v1.22.5
  * chore: use latest-available Markdown linting Docker image
  * chore: manually update Vale and markdownlint rules from GitLab
    project
  * chore: Second (final) pass through docs / UI strings
  * fix(view/list release): use url returned from API as link
  * chore(deps): update module golang.org/x/crypto to v0.25.0
  * fix(snippet create): use filename when path missing
  * feat(snippets): allow creation of personal snippets
  * chore: Updating goreleaser config to v2
  * fix(issuable note): respect editor from config
  * chore: finish the UI string pass
  * chore: String fixes for project-related strings
  * chore: fix strings related to merge requests
  * fix: allow listening hostname to be provided
  * feat: remove experimental wording for duo
  * chore: Yet more string cleanup
  * fix(config): ignore windows config file permission checks
  * chore: ensure user's settings don't impact tests
  * chore: Fix capitalization and punctuation in commands
  * chore: Fix punctuation and phrasing in messages
  * chore(deps): update dependency danger-review to v1.4.1
  * chore: add goleak testing for goroutine leaks
  * fix: always stop spinner to avoid to mess up the terminal
  * chore(deps): update module github.com/zalando/go-keyring to
    v0.2.5
* Mon Jun 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.43.0:
  * chore: Merge security fork
  * chore(deps): update dependency danger-review to v1.4.0
  * docs: add details to stack command
  * chore: remove alias for `ask` and `git` as part of `duo`
  * chore: switch to heredoc v2
  * perf: always skip check-update after completion command
  * fix: Require CLI configuration file to have 0600 permissions
  * fix(auth status): move warning to end of auth status
  * chore(deps): update module github.com/spf13/cobra to v1.8.1
* Mon Jun 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.42.0:
  * feat(stacked-diffs): add stacked diffs feature
  * Revert "Merge branch..."
  * ci: use the danger-review component
  * fix: require user configuration files to only have 600
    permissions
  * chore(deps): update module github.com/briandowns/spinner to
    v1.23.1
  * feat(mr create): Add --signoff option
  * feat(user): Add json format option to events
  * chore(deps): update module k8s.io/client-go to v0.30.2
  * chore(deps): update golang to v1.22.4
  * fix: Mention all available token environment variables in
    warning
  * chore: remove multi-version Go testing from CI
  * chore(deps): update github.com/hashicorp/go-retryablehttp to
    v0.7.7
  * chore(ci): fail on linting issues
  * chore(deps): update module github.com/gdamore/tcell/v2 to
    v2.7.4
  * chore(deps): update module golang.org/x/text to v0.16.0
  * chore(deps): update module github.com/otiai10/copy to v1.14.0
  * chore(deps): update module github.com/charmbracelet/glamour to
    v0.7.0
  * chore(deps): update module golang.org/x/term to v0.21.0
  * chore(deps): update dependency golang to v1.22.3
  * chore: update docs linting image and check Markdown links in
    pipelines
  * chore(deps): update module github.com/spf13/viper to v1.19.0
  * fix(cluster agent): fix joining KAS proxy subpaths
  * chore: fix code_navigation job for latest GO_VERSION
  * docs: minor update to GitLab Duo title
  * chore(deps): update module github.com/makenowjust/heredoc to v2
  * chore(deps): update module github.com/muesli/termenv to v0.15.2
  * chore(deps): update module github.com/mattn/go-isatty to
    v0.0.20
* Wed May 29 2024 pdostal@suse.com
- Update to version 1.41.0:
  * feat(issue): add epic and due-date to issue create
  * chore(deps): update dependency go to v1.22.3
  * chore(deps): update module github.com/xanzy/go-gitlab
    to v0.105.0
  * chore(deps): update module github.com/spf13/viper to v1.18.2
  * fix(cluster-agent): construct kubeconfig authinfo name with
    agent id
  * feat: rename `ask git` to `duo ask`
  * chore(deps): update module github.com/hashicorp/go-version
    to v1.7.0
  * docs: improve integration test docs
  * docs: clarify that fill option automatically pushes
  * chore(deps): update dependency axios to ^1.7.2
  * chore(deps): update dependency @commitlint/format to ^19.3.0
  * fix(auth status): better output for auth status
  * chore(deps): update module golang.org/x/term to v0.20.0
  * chore(deps): update module github.com/mattn/go-runewidth
    to v0.0.15
  * chore(deps): update module k8s.io/client-go to v0.30.1
  * chore(deps): update module golang.org/x/text to v0.15.0
  * docs: Fix broken or redirecting links
  * chore(deps): update module gopkg.in/yaml.v2 to v3
  * chore(deps): update module github.com/spf13/cobra to v1.8.0
  * chore: update code nagivation to use scip
  * chore(deps): update module github.com/spf13/cast to v1.6.0
  * chore(deps): update module github.com/zalando/go-keyring
    to v0.2.4
  * chore(deps): update module github.com/alecaivazis/survey/v2
    to v2.3.7
  * chore: upgrade to Go 1.22
  * feat(cluster):  Add check manifest usage command
  * build: Updating golanglint recommendation
  * fix(glab repo fork): clone if --clone flag set
  * test: fixing error running integration test locally
  * fix(project): don't request statistics
  * fix(auth status): exit with code 1 when auth fails
  * chore: fix typo in Dangerfile
  * refactor: Moving test helper functions to their own file
    for reuse
  * chore: Add a Maintainer Onboarding issue template
  * test: have git tests actually use git instead of stubs
* Thu Apr 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.40.0:
  * feat: allow to provide custom client-id
  * chore(deps): Update retry-go dependency
  * feat(release): support `direct_asset_path` and alias `filepath`
  * chore(ci): remove deprecated
    Jobs/License-Scanning.latest.gitlab-ci.yml
  * fix(docs): w/o issue-no, the example will fail
  * chore(docs): update dependencies for commit-lint script
  * chore: run tests with Go 1.22
  * feat: Create a job artifact command
  * test: fix issue with environment variables being set
  * chore(deps): update github.com/xanzy/go-gitlab to v0.103.0
  * docs(config): update editor and browser config docs
* Thu Apr 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.39.0:
  * feat: Add new command to run Pipeline Triggers
  * fix(deps): update github.com/xanzy/go-gitlab to v0.101.0
  * fix(issue list): change output flag back to output-format
  * fix(test): update test data for updated
    github.com/xanzy/go-gitlab
  * fix: Getting the last pipeline is broken with merged results
  * fix: update "glab ci run-trig" to use new go-gitlab functions
  * refactor: Moving sanitize function to utilities
* Sat Apr  6 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.38.0:
  * fix: updating golang version
  * feat(checkout): Fixing bug with private forks
  * refactor: Refactor code that returns buffer contents in tests
  * chore: fix typo in trigger command docs
  * chore: fix typo support -> supported
* Sun Mar 31 2024 chris@computersalat.de
- fix deps
  * BuildRequires:  golang-packaging
    is not available for RedHat & Co
  * build: upgrade go version from 1.19 to 1.21
    https://gitlab.com/gitlab-org/cli/-/releases
* Fri Mar  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 1.37.0:
  * feat: Json output
  * fix: support transparent background on all tui views
  * fix: reorganise commands/variable/update like
    commands/variable/set
  * docs: Add a stub changelog file
  * fix: ci trigger does interactively ask for job (#7462)
  * feat(ci): add compile command to show full ci config
  * chore: Vale and Markdown rule refresh for project
  * docs: Add mention of 1Password collaboration
  * chore: Update .gitlab-ci.yml - use GO_VERSION var for
    code_navigation
  * fix(release): use link to display release URL
  * fix: change `repo list` alias from `users` to `ls`
  * fix: use gitlab.Client.BaseURL to build release upload URL
  * docs(sourcefile): fix gitFlags comment
  * docs: add glab ask GitLab Duo docs to README
  * docs: document SemVer adoption and usage
  * chore(dependency): update to github.com/google/renameio/v2
  * build: upgrade go version from 1.19 to 1.21
  * docs: Lint URL fragments for validity
  * feat(pagination): add pagination to release list
  * feat(schedule): add option to create a scheduled pipeline with
    variables
  * feat(lint): provide dry-run, include-jobs and ref options
  * chore: remove deprecated `config init` command
* Thu Dec 14 2023 kastl@b1-systems.de
- Update to version 1.36.0:
  * feat: use ciutils.getJobId in trigger cmd (#7424)
  * fix: prefer CTRL+D for cancel job (#1286)
  * docs: add information about docker image
  * feat(ci-delete): add flags for filtering and pagination
  * feat(ci): add ci trigger (#682)
  * feat(ci): align job id resolution ( #7422)
  * feat(ci): add flag with-job-details to output job data as table
    (#1226)
  * docs: clarify archived flag on repo clone
  * docs: Create minimal template for docs MRs
  * fix: git-credential command by using oauth2 user
  * docs: Statement of support for GitLab 16.0
  * chore: update Vale and Markdownlint versions and configuration
  * feat(delete): Add perpage and page flags to ssh-key delete
    command
  * feat(repo): add option to limit list in one group
  * feat: add --web to glab ci view command
  * chore: Do not set CGO_ENABLED when running tests
  * fix(mr create): support non-english languages
* Fri Nov 10 2023 Johannes Kastl <kastl@b1-systems.de>
- adapt BuildRequires to allow building on
  Fedora/RHEL/CentOS/Almalinux/RockyLinux
- BuildRequire go1.19 on openSUSE
* Tue Nov  7 2023 kastl@b1-systems.de
- Update to version 1.35.0:
  * feat(set): add raw flag for set variable command
  * chore(templates): Add environment information section to bug
    template
  * fix(repo search): Fix missing color reset and broken links in
    Bash
  * chore: Bump minimum supported Go version to 1.19
  * feat(cluster): Implement basic `update-kubeconfig` command
  * feat(get): add perpage and page options to ssh-key get command
  * fix(mr create): better error message when no accces
* Tue Oct 24 2023 kastl@b1-systems.de
- Update to version 1.34.0:
  * fix(ci variable list): print entity type
  * docs: Adding precedence order to docs
  * fix: upgrade x/net
  * chore: Fixing lint job for CI
  * feat(sshkey): add ssh-key delete command
  * feat(cluster): implement cluster agent `get-token` command
  * Revert "Merge branch 'nh/pin-gitlab-dangerfiles-version' into
    'main'"
  * chore: Pin gitlab-dangerfiles version
  * chore(dependency): remove alecthomas/assert module
  * chore(dependency): remove jarcoal/httpmock
  * fix: Parse string arrays passed to glab api --field command
  * feat(cluster): add cluster agent list command
  * feat: Add note about homebrew zsh for completions
  * fix: only show web login for GitLab SaaS
  * test(repo clone): seperate integration tests
* Thu Sep 21 2023 kastl@b1-systems.de
- Update to version 1.33.0:
  * feat: prefill scope parameter for PAT generation
  * chore: Update which docs files are linted
  * fix(check-update): remove auth for check-update
  * docs: Add feature design guidelines
  * docs(mr delete): change close to delete
  * fix(auth login): encode scopes for oauth url
  * docs(config): add check_update and display_hyperlinks
  * fix: Fix errors which show up when running `make check'
  * fix: glab ci status needs terminal on stdin
  * chore: update golangci-lint image
  * docs: Add note about maintainership
* Tue Aug 22 2023 pdostal@suse.com
- Update to version 1.32.0:
  * feat: handle response from VertexAI instead of OpenAI
  * feat: add support for child pipelines in ci view
  * fix: Don't add glab-resolved when it already exists in a remote
  * feat(ci): add Pipeline IID to `ci list`
  * fix(deps): upgrade go-gitlab to v0.88.0
  * fix(issue): fix using issue commands from non-git dir
  * test: Fix test Test_repoArchive_Integration integration test
  * chore: use latest tview version
  * chore: downgrade tview
  * fix: Handle trailing slash in remote URL
  * fix(ci run): use correct default branch
  * release: fix assets-links suggestion/help
  * fix: use basereporemote.name as argument to GetDefaultBranch
  * chore: enable better debugging for flaky test
  * docs: clarify possible options for parameters for "ci list"
  * chore(ci): save test log as an artifact
  * chore: bumping go-gitlab to 0.86.0
  * chore(ci): remove ssh key from build
  * fix: goreleaser deprecated replacements, fixing the filename templates
  * fix: Preventing a panic when not using a sub command
  * feat: add incident note command
  * chore: use new test repo for clone integration tests
  * fixup! set error context in mrBody
  * fixup! no index trickery, compare values
  * feat(mr): populate description from commit messages
  * refactor(mr): split mrBody out of mrBodyAndTitle
* Wed Jun 28 2023 pdostal@suse.com
- Update to version 1.31.0:
  * chore: Sync canonical repo
  * fix(repo view): consider current host when viewing a repo details
  * chore: Keeping in regular repo in sync
  * docs: add installation options with wakemeops
  * docs: fix mr create example
  * chore: Continue to rename 'when pipeline succeeds' to 'auto merge'
  * docs: Clarifying method change when using --update for api command
  * feat(incident): add incident subscribe command
  * chore: Renames strings to auto-merge
  * fix: Update multiple labels bug for glab mr create labels
  * feat(schedule): Fixed broken test for delete schedule
  * fix(check-update): always show error when check-update fails
  * feat(schedule): Add commands to create and delete schedules
  * feat(mr/checkout): Track by default without adding extra remotes
  * fix: Adjusting timeout value to prevent hangs
  * feat: Make mr create prompt for reviewers
  * fix(check-update): remove unicode characters in favor of ascii
  * fix(repo list): #1327 fix filters
* Sat May 20 2023 pdostal@suse.com
- Update to version 1.30.0:
  * feat: better error messages for no matching remotes
  * chore: Updating snapcraft info
  * feat: add new changelog command
  * fix(ci): Fixed issue with API deprecation for CI lint
  * chore: stop overwriting config file in test
* Sun May 14 2023 kastl@b1-systems.de
- Update to version 1.29.4:
  * fix(ci): Fixed issue with API deprecation for CI lint
  * chore: Fix typos in new AI commands
  * docs: change release process not to push all tags
  * chore: stop overwriting config file in test
  * chore: use testdata dir rather than fixtures
* Thu May 11 2023 kastl@b1-systems.de
- Update to version 1.29.3:
  * fix(auth login): use token when logging in
* Thu May 11 2023 kastl@b1-systems.de
- Update to version 1.29.2:
  * feat(ask): add a message that the ask-git response are
    AI-generated
  * feat(incident): add incident unsubscribe command
  * refactor: move issue/unsubscribe to issuable/unsubscribe
* Tue May  9 2023 kastl@b1-systems.de
- Update to version 1.29.1:
  * chore: downgrade tview
* Fri May  5 2023 kastl@b1-systems.de
- Update to version 1.29.0:
  * feat(ci delete): add dry-run flag to ci delete
  * fix(ask git): do not show prompt when no commands
  * feat: add command that generates Git commands from natural
    language
  * docs: add OAuth to authentication instructions
  * feat(auth login): Add support for OAuth2
  * feat: update go and dependency versions
  * fix(spinner): Bump spinner library version
  * refactor: autogenerate config stub from lockfile
  * feat(incident): add incident reopen command
  * fix: remove executable flag from non-executables
  * fix: do not enforce argument for 'ci delete' when using filter
  * refactor(release): update `release download` cmd to remove
    `external`
  * refactor: move issue/close to issuable/close
  * test: add some test to improve coverage
  * docs: update godoc for function
* Mon Apr 24 2023 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording and duplicate info (present in License field).
* Mon Apr 24 2023 kastl@b1-systems.de
- Update to version 1.28.1:
  * docs: Update installation_options.md
  * docs: update string for merge request flag on repo
  * docs: et cetera without dots
  * docs: Update README.md - fix punctuation
  * fix: Disable breaking test for CI Lint endpoint
  * chore: fix broken link
  * chore: improve documentation visibility
  * chore: replace README badges with native project badges
  * fix: add newline to auth status command output
  * test: fix Test_getFromKeyring not passing in CI
  * test: fix assertion order, clear token in keyring test
  * chore: update use-keyring flag description
  * test: add tests for loading and storing tokens in keyring
  * chore: update docs, fix lint error
  * chore: replace native keyring with os keyring in login argument
    desc
  * docs: regenerate the docs
  * feat: add support for token storage in encrypted keychains
* Thu Apr 13 2023 pdostal@suse.com
- Update to version 1.28.0:
  * chore: simpler installation method from binary if Go is available
  * fix: Change platform generating code
  * fix: purposely adding the "v" goreleaser strips out
  * refactor: default check_update true on new install
  * chore: modify MIT license and inspiration
  * feat(incident): add `incident close` command
  * refactor: move issue/close to issuable/close
* Thu Apr  6 2023 kastl@b1-systems.de
- Update to version 1.27.1:
  * chore: upgrade go-gitlab to 0.81.0
  * chore: fix testing repo to a local GitLab one
  * feat(docs): Add aliases to gen-docs
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 1.27.0:
  * chore: security release merge
  * fix: markdown fence shell script needs to be "shell"
  * feat(pagination): add pagination to user events
  * chore: update golang/x/net package
  * fix(variable set): scope for group variables
  * refactor(test): replace os.Setenv with t.Setenv in tests
  * docs: configuration for self-signed certs
  * fix(test): use gray256 color in tests when enabled
  * fix(color): fix gray color for 256 color terminal
  * test(glab auth login): use temp config for test
  * docs: fix link to issue command in index
  * fix(issue): display list of comments in raw format
  * docs(config): clarify config help
  * docs(readme): clarify config file location and environment
    variables
  * feat(label): display label colors in the list
  * security: Remove configuration import for old locations
* Wed Mar 15 2023 kastl@b1-systems.de
- set tar and recompress services to "buildtime"
- use obscpio file for local go-modules run
- cleanup spec file, remove old %%go macros
- Update to version 1.26.0:
  * Merge security fix for v1.26.0 release
  * refactor(test): use http constants in tests
  * refactor: use HTTP constants in code
  * chore: Remove profclems/glab from .goreleaser.yml
  * chore: add debug environment variable to Makefile
  * chore: remove build date and add architecture
  * refactor(project): Stop requsting for README when viewing
    project on web
  * docs: add guidelines for triaging bugs
  * chore: Modify UserAgent to be more like other CLIs
  * docs: self-managed doc improvements
  * docs: fix link to issue command in README
  * chore(ci/test): separate integration tests
  * docs: update core commands with links
  * fix(issue create): better error message when users are not
    members
  * docs: reword homebrew section
  * docs: Build jump list of core commands
  * docs(installation): Add asdf-vm to install options
  * feat: variable export
  * docs: specify [flags] position in clone command
  * feat(schedule): Add command to run schedules
  * refactor: use strings.Join in comma separated list functions
  * fix(repo): URL encode branch name when viewing on web
  * refactor(test): combine issue/incident list tests
  * refactor(issue/view): extract issuable/list package
  * fix(project): Remove repo override functionality
  * chore: Add test-race make target
  * ci: lock down go lint image version
  * docs: Add Fedora to installation options
  * docs: Updating instructions for homebrew release
  * ci(coverage): report correct coverage
  * fix(ci): Fix issue where `ci get` fails if user is not
    maintainer
  * fix: check-update command output to StdErr
  * refactor(test): adjust issuable tests to cover both types
  * refactor(issue/view): extract issuable/view package
  * chore: Expose make gen-docs task
  * chore: Run tests in different Go versions
  * fix: making sure homebrew doesn't try to open a browser
  * test: fix timing issue with release tests
* Wed Mar 15 2023 Johannes Kastl <kastl@b1-systems.de>
- adapt to new URL https://gitlab.com/gitlab-org/cli
- BuildRequire go1.18
* Tue Feb  7 2023 pdostal@suse.com
- Update to version 1.25.3:
  * Update .gitlab-ci.yml file
  * Update .gitlab-ci.yml file
  * chore: better omit test and chores from changelog
  * fix: Adding git name/email for homebrew
  * docs: update installation instructions for windows
  * test(project): add missing project tests
  * fix(project): fixes issue with filtering with starred and membership
  * fix(mr): Fixed EOF error when todo is called multiple times
* Tue Jan 11 2022 Orville Q. Song <orville@anislet.dev>
- Update to version 1.22.0:
  * feat: Add group flag to mr list command (#931)
  * chore: Update Arch README link to official repos
  * fix: Write aliases to symlink if it exists (#930)
  * added push mirror and command (#887)
  * feature: Read config directory from GLAB_CONFIG_DIR (#921)
  * feature: add variable update command (#902)
  * feat(mr): Only output MR URL to stdout if output is not a TTY (#883)
  * fix(mr_create/issue_create): add encoding to title and change description encoding (#871)
  * fix: add linebreak to check-output msg (#895)
  * mr: deprecate `mr for` command
  * Require Go 1.17+ (#898)
  * feature: add variable delete command (#890)
  * Add support for terminal hyperlinks (#852)
  * Update docs for `ci run` to include passing variables
  * commands/project/create: fix typo
  * update dependencies (#884)
  * fix: allow setting variable without using --value (#881)
  * fix: obsolete %% char for weights
  * fix(mr-create): escape titles in new MR preview URLs
  * fix(ci status): add check for pending pipelines
  * refactor: rename Squash to SquashBeforeMerge
  * Handle invalid job id
  * Apply improvements from code review
  * feat(command/ci/retry): Add new command to retry CI jobs
  * Update README.md
  * Update README.md
  * docs(README): add awesome-go badge to README
  * fix: weird condition when prompt disabled
  * feat(mr update): add --squash parameter
  * fix ci pipeline view incorrect timestamp being used
  * ci: fix the linter by targeting the pull request instead of the target
  * refactor: rename Squash to SquashBeforeMerge
  * chore: remove colon
  * docs(template): use different header styles for the Pull Request template
  * feat(mr create): add --squash parameter
  * docs(mr create): remove doc entry as it's automatically generated
  * docs(mr create): add --reviewer parameter to docs
  * feat(mr create): add --reviewer parameter
  * chore: use errors.Is instead of error equality
  * docs(readme): update Fosshost.org logo location
  * add remoteName flag to 'create project' command
  * fix(ci trace): exit normally when prompts are interrupted
  * docs: remove --autofill references
  * docs(update): v1.21.1
* Tue Jan  4 2022 Orville Q. Song <orville@anislet.dev>
- Fix for reproducible builds
* Sun Dec  5 2021 Orville Q. Song <orville@anislet.dev>
- Update to version 1.21.1:
  * fix debian packaging installer location
  * auth login use OverridableDefault
  * Login using default hostname string
  * Move glinstance to pkg
  * {go.mod,go.sum}: update dependencies
  * api: fix wrong comment
  * fix: error 404 when creating release
  * Handle paginated response in pipeline.GetPipelineJobs
  * Update ssh-key.go
  * feat(cmdutils): Add group milestones to the prompt
* Sat Dec  4 2021 Orville Q. Song <orville@anislet.dev>
- Init glab Package
  An open-source GitLab command line tool bringing GitLab's cool features to your command line.
  Current Version: v1.21.1
  Commit Hash: 5cb2858d1fb7a5317e89259fc4ac135414e99be2
